@@ -10,6 +10,23 @@
 /* #define DEBUG  */
 
 #include <includes.h>
+#include "nasl.h"
+
+#if NASL_LEVEL >= 3203 
+int 
+plugin_init( struct arglist *desc )
+{
+ return -1;
+}
+
+int plugin_run( struct arglist *desc )
+{
+ return -1;
+}
+
+#else
+
+ 
 
 #define EN_NAME "Services"
 #define FR_NAME "Services"
@@ -58,8 +75,9 @@ int
 plugin_init(desc)
 	struct arglist *desc;
 {
+
 	plug_set_id(desc, 10330);
-	plug_set_version(desc, "$Revision: 1.260 $");
+	plug_set_version(desc, "$Revision: 1.261 $");
 
 	plug_set_name(desc, FR_NAME, "francais");
 	plug_set_name(desc, EN_NAME, NULL);
@@ -1756,6 +1774,7 @@ known_ssl_port(int port)
 		case 614:	/* SSLshell */
 		case 636:	/* LDAPS */
 		case 684:	/* Corba IIOP SSL */
+		case 902:	/* VMWare auth daemon */
 		case 989:	/* FTPS data */
 		case 990:	/* FTPS control */
 		case 992:	/* telnets */
@@ -1764,7 +1783,7 @@ known_ssl_port(int port)
 		case 995:	/* POP3S */
 		case 1241:	/* Nessus */
 	        case 1311:	/* Dell OpenManage */
-	 	case 2050:	/* Domino */
+		case 2050:	/* Domino */
 		case 2381:	/* Compaq Web Management (HTTPS) */
 		case 2478:	/* SecurSight Authentication Server (SSL) */
 		case 2479:	/* SecurSight Event Logging Server (SSL) */
@@ -2682,6 +2701,7 @@ plugin_run(desc)
 	char           *cafile = get_plugin_preference(desc, CA_FILE);
 	char           *test_ssl_s = get_plugin_preference(desc, TEST_SSL_PREF);
 
+	if ( NASL_LEVEL >= 3203 ) exit(0);
 	
 
 	if (key && key[0] != '\0')
@@ -2884,3 +2904,4 @@ again:
 
 	return 0;
 }
+#endif
