@@ -8,6 +8,11 @@
  */
  
 #include "includes.h"
+#include "nasl.h"
+
+#if NASL_LEVEL < 3000
+#define strlcat(x,y,z) strncat((x),(y),(z) - strlen((x)) - 1)
+#endif
 
 #ifndef ssl_get_cipher_by_char
 #define ssl_get_cipher_by_char(ssl,ptr) \
@@ -39,7 +44,7 @@ PlugExport int plugin_init(desc)
   return -1;
 #else
   plug_set_id(desc, 10863);
-  plug_set_version(desc, "$Revision: 1.15 $");
+  plug_set_version(desc, "$Revision: 1.20 $");
  
   plug_set_name(desc, EN_NAME, NULL);
   
@@ -48,7 +53,11 @@ PlugExport int plugin_init(desc)
   plug_set_copyright(desc, COPYRIGHT, NULL);
   plug_set_category(desc, ACT_GATHER_INFO);
   plug_set_family(desc, "General", NULL);
+#if NASL_LEVEL >= 3203 
+  plug_set_dep(desc, "find_service.nasl");
+#else
   plug_set_dep(desc, "find_service.nes");
+#endif
   return 0;
 #endif
 }
@@ -73,10 +82,9 @@ static int report_cat(char ** report, int * report_sz, char * msg)
   *report = erealloc(*report, *report_sz);
  }
 
- strcat(*report, msg);
-
+ strlcat(*report, msg, *report_sz);
  if ( msg[strlen(msg) - 1] != '\n' )
-	strcat(*report, "\n");
+	strlcat(*report, "\n", *report_sz);
 }
 
 
