@@ -404,6 +404,16 @@ extractseq(char *pkt, int len)
 	return ret;
 }
 
+int
+extractttl(char * pkt, int len )
+{
+ struct ip * ip;
+
+ if ( len < sizeof(struct ip) ) return;
+ ip = (struct ip*) pkt;
+ return ip->ip_ttl;
+}
+
 
 unsigned short 
 extractsport(char *pkt, int len)
@@ -585,7 +595,7 @@ int find_rtt(struct in_addr dst, struct sockaddr_in6 * sin6, unsigned long *rtt)
 		errno = 0;
 		e = sendto(soc, pkt, plen, 0, so, so_sz);
 		if (e < 0) {
-			perror("synscan->find_rtt->sendto ");
+			fprintf(stderr, "[%d] synscan->find_rtt->sendto failed: %s\n", getpid(), strerror(errno));
 			close(soc);
 			bpf_close(bpf);
 			return -1;
@@ -627,7 +637,7 @@ int find_rtt(struct in_addr dst, struct sockaddr_in6 * sin6, unsigned long *rtt)
 		e = sendto(soc, pkt, plen, 0, so, so_sz);
 		if (e < 0)
 			{
-			 perror("synscan->find_rtt(2)->sendto ");
+			 fprintf(stderr, "[%d] synscan->find_rtt(2)->sendto failed: %s\n", getpid(), strerror(errno));
 			 close(soc);
 			 bpf_close(bpf);
 			 return -1;
@@ -729,7 +739,7 @@ send:
 				  goto send;
 				}
 			}
-			perror("synscan->sendpacket->sendto ");
+			fprintf(stderr, "[%d] synscan->sendpacket->sendto failed: %s\n", getpid(), strerror(errno));
 			return SCAN_FATAL_ERR;
 		}
 	}
@@ -742,9 +752,11 @@ again:
 			int             synack = issynack(res + skip, len);
 			unsigned int rack = extractack(res + skip, len);
 			unsigned int rseq = extractseq(res + skip, len);
+			int ttl = extractttl(res + skip, len);
 			if (synack) {
 			  char * rst;
 			  int    len;
+			  char   key[1024];
 #ifdef DEBUG
 				printf("=> Port %d is open\n", sport);
 #endif
@@ -756,7 +768,8 @@ again:
 			  /* Adjust the rtt */
 			  *rtt = compute_rtt(rack);
 			  if ( ntohl(*rtt) >= ( 1 << 28 ) ) *rtt = htonl(1 << 28);
-
+			  snprintf(key, sizeof(key), "SynScan/TTL/%d", sport);
+			  plug_set_key(env, key, ARG_INT, (void*)ttl);
 			}
 			ipcd();
 			packets = rm_packet(packets, sport);
@@ -877,7 +890,7 @@ PlugExport int
 plugin_init(struct arglist * desc)
 {
 	plug_set_id(desc, 11219);
-	plug_set_version(desc, "$Revision: 1.28 $");
+	plug_set_version(desc, "$Revision: 1.30 $");
 
 
 
